==> c-3po-0.7.1.tgz: package/src/config.js <==
import { transformTranslateObj } from './utils';
import { validateLocaleData, validateLocales, validateLocaleCode } from './validation';

const defaultHeaders = {
    'content-type': 'text/plain; charset=UTF-8',
    'plural-forms': 'nplurals=2; plural=(n!=1);',
};

const isProd = process && process.env && process.env.NODE_ENV === 'production';

export default function Config() {
    const config = {
        locales: {},
        currentLocales: [],
        currentLocale: 'en',
        dedent: true,
        headers: defaultHeaders,
    };

    this.addLocale = (locale, localeData) => {
        if (!isProd) validateLocaleCode(locale);
        if (!isProd) validateLocaleData(localeData);
        localeData = transformTranslateObj(localeData);
        config.locales[locale] = localeData;
    };

    this.setCurrentLocale = (locale) => {
        config.currentLocale = locale;
    };

    this.setDedent = (dedent) => {
        config.dedent = dedent;
    };

    this.setHeaders = (headers) => {
        config.headers = headers;
    };

    this.setCurrentLocales = (locales) => {
        if (!isProd) validateLocales(locales, this.getAvailLocales());
        config.currentLocales = locales;
    };

    this.getAvailLocales = () => {
        return config.locales;
    };

    this.getCurrentLocales = () => {
        return config.currentLocales;
    };

    this.getCurrentLocale = () => {
        return config.currentLocale;
    };

    this.isDedent = () => {
        return config.dedent;
    };

    this.getHeaders = () => {
        return config.headers;
    };
}

==> c-3po-0.8.0.tgz: package/src/config.js <==
import { transformTranslateObj } from './utils';
import { validateLocaleData, validateLocales, validateLocaleCode } from './validation';
import { getPluralFunc, getNPlurals } from 'plural-forms/dist/minimal';

const isProd = process && process.env && process.env.NODE_ENV === 'production';

export default function Config() {
    const config = {
        locales: {},
        currentLocales: [],
        currentLocale: 'en',
        dedent: true,
        defaultLang: 'en',
    };

    this.addLocale = (locale, localeData) => {
        if (!isProd) validateLocaleCode(locale);
        if (!isProd) validateLocaleData(localeData);
        localeData = transformTranslateObj(localeData);
        config.locales[locale] = localeData;
    };

    this.setCurrentLocale = (locale) => {
        config.currentLocale = locale;
    };

    this.setDedent = (dedent) => {
        config.dedent = dedent;
    };

    this.setCurrentLocales = (locales) => {
        if (!isProd) validateLocales(locales, this.getAvailLocales());
        config.currentLocales = locales;
    };

    this.getAvailLocales = () => {
        return config.locales;
    };

    this.getCurrentLocales = () => {
        return config.currentLocales;
    };

    this.getCurrentLocale = () => {
        return config.currentLocale;
    };

    this.isDedent = () => {
        return config.dedent;
    };

    this.setDefaultLang = (lang) => {
        config.defaultLang = lang;
    };

    this.getDefaultPluralFn = () => {
        return getPluralFunc(config.defaultLang);
    };

    this.getDefaultPluralFormsCount = () => {
        return getNPlurals(config.defaultLang);
    };

    this.getCurrentLocaleHeaders = () => {
        return config.locales[config.currentLocale].headers;
    };
}
